pub struct CitationKey {
pub id: String,
pub prefix: Option<String>,
pub locator: Option<String>,
}Expand description
A single citation key with optional prefix and locator.
Fields
id: Stringprefix: Option<String>locator: Option<String>Trait Implementations
Sourceimpl Archive for CitationKey
impl Archive for CitationKey
Sourceconst COPY_OPTIMIZATION: CopyOptimization<CitationKey>
const COPY_OPTIMIZATION: CopyOptimization<CitationKey>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedCitationKey
type Archived = ArchivedCitationKey
The archived representation of this type. Read more
Sourcetype Resolver = CitationKeyResolver
type Resolver = CitationKeyResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for CitationKey
impl Clone for CitationKey
Sourcefn clone(&self) -> CitationKey
fn clone(&self) -> CitationKey
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CitationKey
impl Debug for CitationKey
Sourceimpl<'de> Deserialize<'de> for CitationKey
impl<'de> Deserialize<'de> for CitationKey
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<CitationKey, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<CitationKey, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D> Deserialize<CitationKey, __D> for <CitationKey as Archive>::Archived
impl<__D> Deserialize<CitationKey, __D> for <CitationKey as Archive>::Archived
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<CitationKey, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<CitationKey, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl PartialEq for CitationKey
impl PartialEq for CitationKey
Sourceimpl<__S> Serialize<__S> for CitationKey
impl<__S> Serialize<__S> for CitationKey
Sourceimpl Serialize for CitationKey
impl Serialize for CitationKey
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for CitationKey
impl StructuralPartialEq for CitationKey