pub struct CodeBlockNode {
pub value: String,
pub lang: Option<String>,
pub meta: Option<String>,
pub title: Option<String>,
pub highlight: Option<Vec<u32>>,
pub show_line_numbers: Option<bool>,
pub diff: Option<bool>,
pub caption: Option<String>,
pub position: Position,
}Expand description
A fenced code block with optional language, meta string, and display metadata.
Fields
value: Stringlang: Option<String>meta: Option<String>title: Option<String>Display title or filename (from info string title="...").
highlight: Option<Vec<u32>>Sorted, deduplicated line numbers to emphasize.
show_line_numbers: Option<bool>Whether to display line numbers.
diff: Option<bool>Whether to render as a unified diff.
caption: Option<String>Caption text for numbered code listings.
position: PositionTrait Implementations
Sourceimpl Archive for CodeBlockNode
impl Archive for CodeBlockNode
Sourceconst COPY_OPTIMIZATION: CopyOptimization<CodeBlockNode>
const COPY_OPTIMIZATION: CopyOptimization<CodeBlockNode>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedCodeBlockNode
type Archived = ArchivedCodeBlockNode
The archived representation of this type. Read more
Sourcetype Resolver = CodeBlockNodeResolver
type Resolver = CodeBlockNodeResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for CodeBlockNode
impl Clone for CodeBlockNode
Sourcefn clone(&self) -> CodeBlockNode
fn clone(&self) -> CodeBlockNode
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CodeBlockNode
impl Debug for CodeBlockNode
Sourceimpl<'de> Deserialize<'de> for CodeBlockNode
impl<'de> Deserialize<'de> for CodeBlockNode
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<CodeBlockNode, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<CodeBlockNode, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D> Deserialize<CodeBlockNode, __D> for <CodeBlockNode as Archive>::Archivedwhere
__D: Fallible + ?Sized,
String: Archive,
<String as Archive>::Archived: Deserialize<String, __D>,
Option<String>: Archive,
<Option<String> as Archive>::Archived: Deserialize<Option<String>, __D>,
Option<Vec<u32>>: Archive,
<Option<Vec<u32>> as Archive>::Archived: Deserialize<Option<Vec<u32>>, __D>,
Option<bool>: Archive,
<Option<bool> as Archive>::Archived: Deserialize<Option<bool>, __D>,
Position: Archive,
<Position as Archive>::Archived: Deserialize<Position, __D>,
impl<__D> Deserialize<CodeBlockNode, __D> for <CodeBlockNode as Archive>::Archivedwhere
__D: Fallible + ?Sized,
String: Archive,
<String as Archive>::Archived: Deserialize<String, __D>,
Option<String>: Archive,
<Option<String> as Archive>::Archived: Deserialize<Option<String>, __D>,
Option<Vec<u32>>: Archive,
<Option<Vec<u32>> as Archive>::Archived: Deserialize<Option<Vec<u32>>, __D>,
Option<bool>: Archive,
<Option<bool> as Archive>::Archived: Deserialize<Option<bool>, __D>,
Position: Archive,
<Position as Archive>::Archived: Deserialize<Position, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<CodeBlockNode, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<CodeBlockNode, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl PartialEq for CodeBlockNode
impl PartialEq for CodeBlockNode
Sourceimpl<__S> Serialize<__S> for CodeBlockNode
impl<__S> Serialize<__S> for CodeBlockNode
Sourceimpl Serialize for CodeBlockNode
impl Serialize for CodeBlockNode
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for CodeBlockNode
impl StructuralPartialEq for CodeBlockNode