pub struct CrossRefNode {
pub target: String,
pub position: Position,
}Expand description
A cross-reference node pointing to a labeled element elsewhere in the document.
Fields
target: Stringposition: PositionTrait Implementations
Sourceimpl Archive for CrossRefNode
impl Archive for CrossRefNode
Sourceconst COPY_OPTIMIZATION: CopyOptimization<CrossRefNode>
const COPY_OPTIMIZATION: CopyOptimization<CrossRefNode>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedCrossRefNode
type Archived = ArchivedCrossRefNode
The archived representation of this type. Read more
Sourcetype Resolver = CrossRefNodeResolver
type Resolver = CrossRefNodeResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for CrossRefNode
impl Clone for CrossRefNode
Sourcefn clone(&self) -> CrossRefNode
fn clone(&self) -> CrossRefNode
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CrossRefNode
impl Debug for CrossRefNode
Sourceimpl<'de> Deserialize<'de> for CrossRefNode
impl<'de> Deserialize<'de> for CrossRefNode
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<CrossRefNode, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<CrossRefNode, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D> Deserialize<CrossRefNode, __D> for <CrossRefNode as Archive>::Archived
impl<__D> Deserialize<CrossRefNode, __D> for <CrossRefNode as Archive>::Archived
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<CrossRefNode, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<CrossRefNode, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl PartialEq for CrossRefNode
impl PartialEq for CrossRefNode
Sourceimpl<__S> Serialize<__S> for CrossRefNode
impl<__S> Serialize<__S> for CrossRefNode
Sourceimpl Serialize for CrossRefNode
impl Serialize for CrossRefNode
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for CrossRefNode
impl StructuralPartialEq for CrossRefNode